@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use warnings;
 use strict;
@@ -166,6 +166,21 @@ sub span {
     return $lightest, $heaviest;
 }
 
+
+sub path_attr {
+    my ($self, $path, $attr) = @_;
+
+    return unless $self->has_path( @$path );
+
+    my $path_attr = 0;
+
+    for my $i ( 0 .. @$path - 2 ) {
+        $path_attr += $self->get_attr( [ $path->[$i], $path->[ $i + 1 ] ] );
+    }
+
+    return $path_attr;
+}
+
 1;
 
 __END__
@@ -180,7 +195,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.55
+version 0.56
 
 =head1 SYNOPSIS
 
@@ -290,6 +305,13 @@ Return the named attribute value for the vertex or edge.
 
 Return the span of lightest to heaviest vertices.
 
+=head2 path_attr()
+
+ my $weight = $gw->path_attr(\@vertices);
+ my $weight = $gw->path_attr(\@vertices, $attr);
+
+Return the summed weight (or given attribute) of the path edges.
+
 =head1 TO DO
 
 Find the total weight beneath a node.
